@@ -2,13 +2,21 @@ package Bb::Collaborate::Ultra::Session::Occurrence;
 use warnings; use strict;
 use Mouse;
 use JSON;
-extends 'Bb::Collaborate::Ultra';
+extends 'Bb::Collaborate::Ultra::DAO';
 use Mouse::Util::TypeConstraints;
 
 =head1 NAME
 
 Bb::Collaborate::Ultra::Session::Occurrence
 
+=head1 DESCRIPTION
+
+Session scheduling subrecord.
+
+=head1 METHODS
+
+See L<https://xx-csa.bbcollab.com/documentation#Session>
+
 =cut
     
 
