@@ -2,7 +2,7 @@ package Bb::Collaborate::Ultra::Session::RecurrenceRule;
 use warnings; use strict;
 use Mouse;
 use JSON;
-extends 'Bb::Collaborate::Ultra';
+extends 'Bb::Collaborate::Ultra::DAO';
 use Mouse::Util::TypeConstraints;
 coerce __PACKAGE__, from 'HashRef' => via {
     __PACKAGE__->new( $_ )
@@ -13,6 +13,14 @@ __PACKAGE__->load_schema(<DATA>);
 
 Bb::Collaborate::Ultra::Session::RecurrenceRule
 
+=head1 DESCRIPTION
+
+Session scheduling subrecord.
+
+=head1 METHODS
+
+See L<https://xx-csa.bbcollab.com/documentation#Session>
+
 =cut
  
 1;
